import javax.swing.text.Segment;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Point;
import java.util.ArrayList;
import java.util.List;

/**
 * A multi-segment Shape, with straight lines connecting "joint" points -- (x1,y1) to (x2,y2) to (x3,y3) ...
 *
 * @author Chris Bailey-Kellogg, Dartmouth CS 10, Spring 2016
 * @author CBK, updated Fall 2016
 * @author Tucker Simpson and Logan Tucker
 */
public class Polyline implements Shape {
	List<MySegment> lines;
	public int x1, x2, y1, y2;
	public Color color;

	/**
	 * Construct polyline wit only starting coordinate
	 */
	public Polyline(int x1, int y1, Color color) {
		lines = new ArrayList<>();
		this.x1 = x1; this.x2 = x1;
		this.y1 = y1; this.y2 = y1;
		this.color = color;
		lines.add(new MySegment(x1, y1, color));
	}

	/**
	 * Construct polyline with starting segment
	 */
	public Polyline(int x1, int y1, int x2, int y2, Color color) {
		lines = new ArrayList<>();
		this.x1 = x1; this.y1 = y1;
		this.x2 = x2; this.y2 = y2;
		lines.add(new MySegment(x1, y1, x2, y2, color));
		this.color = color;
	}

	/**
	 * Construct polyline with list of segments and color
	 */
	public Polyline(List<MySegment> lines, Color col){
		if(lines.size()>0) {
			x1 = lines.get(0).getX1();
			y1 = lines.get(0).getY1();
			x2 = lines.get(lines.size() - 1).getX2();
			y2 = lines.get(lines.size() - 1).getY2();
		}
		this.lines = lines;
		this.color = col;
	}

	/**
	 * Set the end of the last segment equal to the current point, start a new segment at the same point, mark end
	 * of polyline at (x2, y2)
	 */
	@Override
	public void setEnd(int curr_x, int curr_y){
		lines.get(lines.size()-1).setEnd(curr_x, curr_y);
		//System.out.println("x2: "+ x2 + ", y2: "+y2);
		lines.add(new MySegment(curr_x, curr_y, color));
		x2 = curr_x;
		y2 = curr_y;
	}

	/**
	 * Add a segment to the polyline manually
	 */
	public void addSeg(MySegment seg){
		lines.add(seg);
	}

	/**
	 * Move every segment in the polyline
	 */
	@Override
	public void moveBy(int dx, int dy) {
		for(MySegment seg : lines){
			seg.moveBy(dx, dy);
		}
	}

	@Override
	public Color getColor() { return color; }

	/**
	 * Recolor every segment in the polyline
	 */
	@Override
	public void setColor(Color color) {
		this.color = color;
		for(MySegment seg : lines) {
			seg.setColor(color);
		}
	}

	/**
	 * Check every segment to see if polyline contains point
	 */
	@Override
	public boolean contains(int x, int y) {
		for(MySegment seg : lines){
			if(seg.contains(x, y)) return true;
		}
		return false;
	}

	/**
	 * Draw every segment in polyline
	 */
	@Override
	public void draw(Graphics g) {
//		g.setColor(color);
		for(MySegment seg : lines) seg.draw(g);
	}

	@Override
	public void setCorners(int x1, int y1, int x2, int y2) {
		;
	}

	/**
	 * Format: "Freehand RGB/x1 y1 x2 y2/x2 y2 x3 y3/etc."
	 * @return
	 */
	@Override
	public String toString() {

		// create string communication of polyline
		// freehand + all coordinates of segments + color

		String res = "freehand " + color.getRGB() + "/";
		for (MySegment seg : lines) {
			String[] s = seg.toString().split(" ");
			res += s[1] + " " + s[2] + " " + s[3] + " " + s[4] + "/";
		}

		return res;
	}

}
