import java.awt.*;
import java.util.TreeMap;

/**
 * Holds a map of shapes and handles multiple users editing map
 * @author tucker simpson, logan tucker
 */
public class Sketch {

    private int id;
    private int currId;


    private TreeMap<Integer, Shape> shapes;

    public Sketch(){
        id = 0;
        currId = -1;
        shapes = new TreeMap<>();
    }

    public synchronized void addShape(Shape shape){
        //check to make sure user is not overwriting any pre-existing shape;
        while(shapes.containsKey(id)){
            //System.out.println("this is the case");
            id ++;
        }
        shapes.put(id, shape);
        currId = id;
    }

    public synchronized TreeMap<Integer, Shape> getShapes() {return shapes;}

    public synchronized void setCurrId(int i){id = i;}

    public synchronized int getCurrId(){ return currId; }

    public synchronized void addShape(Shape shape, int id){
        shapes.put(id, shape);
    }

    public synchronized void recolorShape(int id, Color col){
        shapes.get(id).setColor(col);
    }

    public synchronized void moveShape(int id, int dx, int dy){
        shapes.get(id).moveBy(dx, dy);
    }

    public synchronized void delShape(int id){
        shapes.remove(id);
    }

    @Override
    public String toString() {
        String rString = "Sketch/";
        rString += "CurrID " + currId +"/";
        for (int id : shapes.descendingKeySet()){
            rString += id + " " + shapes.get(id).toString() + "/";
        }
        return rString;
    }

}
